@@ -11,7 +11,10 @@ class AdminMixin:
     def get_fields_for_request(self, request):
         if hasattr(request, "data_browser"):
             return request.data_browser["fields"]
-        elif request.resolver_match.func.__name__ == "changelist_view":
+        elif (
+            request.resolver_match
+            and request.resolver_match.func.__name__ == "changelist_view"
+        ):
             return set(self.get_list_display(request))
         else:
             return Everything()
