@@ -1,10 +1,14 @@
+from collections import defaultdict
 from dataclasses import dataclass
 from typing import Sequence, Tuple
 
+import django
 from django.contrib.admin.options import BaseModelAdmin
 from django.db import models
 from django.db.models import (
     BooleanField,
+    DateField,
+    DurationField,
     ExpressionWrapper,
     IntegerField,
     OuterRef,
@@ -21,9 +25,12 @@ from .types import (
     BooleanType,
     DateTimeType,
     DateType,
+    DurationType,
     HTMLType,
+    IsNullType,
     MonthType,
     NumberType,
+    StringChoiceType,
     StringType,
     WeekDayType,
     YearType,
@@ -31,29 +38,69 @@ from .types import (
 
 OPEN_IN_ADMIN = "admin"
 
-_TYPE_AGGREGATES = {
-    StringType: ["count"],
-    NumberType: ["average", "count", "max", "min", "std_dev", "sum", "variance"],
-    DateTimeType: ["count"],  # average, min and max might be nice here but sqlite
-    DateType: ["count"],  # average, min and max might be nice here but sqlite
-    BooleanType: ["average", "sum"],
-}
+_TYPE_AGGREGATES = defaultdict(
+    lambda: [("count", NumberType)],
+    {
+        StringType: [("count", NumberType)],
+        StringChoiceType: [("count", NumberType)],
+        NumberType: [
+            ("average", NumberType),
+            ("count", NumberType),
+            ("max", NumberType),
+            ("min", NumberType),
+            ("std_dev", NumberType),
+            ("sum", NumberType),
+            ("variance", NumberType),
+        ],
+        DateTimeType: [  # average, min and max might be nice here but sqlite
+            ("count", NumberType)
+        ],
+        DateType: [  # average, min and max might be nice here but sqlite
+            ("count", NumberType)
+        ],
+        DurationType: [
+            ("count", NumberType),
+            ("average", DurationType),
+            ("sum", DurationType),
+            ("max", DurationType),
+            ("min", DurationType),
+        ],
+        BooleanType: [("average", NumberType), ("sum", NumberType)],
+        YearType: [("count", NumberType), ("average", NumberType)],  # todo min and max
+    },
+)
 
-_TYPE_FUNCTIONS = {
-    DateTimeType: [
-        "year",
-        "quarter",
-        "month",
-        "day",
-        "week_day",
-        "hour",
-        "minute",
-        "second",
-        "date",
-    ],
-    DateType: ["year", "quarter", "month", "day", "week_day"],
-    None: ["is_null"],  # all fields
-}
+
+_DATE_FUNCTIONS = [
+    "is_null",
+    "year",
+    "quarter",
+    "month",
+    "day",
+    "week_day",
+    "month_start",
+]
+if django.VERSION >= (2, 2):  # pragma: no branch
+    _DATE_FUNCTIONS += ["iso_year", "iso_week", "week_start"]
+
+
+_TYPE_FUNCTIONS = defaultdict(
+    lambda: ["is_null"],
+    {
+        DateType: _DATE_FUNCTIONS,
+        DateTimeType: _DATE_FUNCTIONS + ["hour", "minute", "second", "date"],
+    },
+)
+
+
+class _CastDuration(Cast):
+    def __init__(self, expression):
+        super().__init__(expression, output_field=DurationField())
+
+    def as_mysql(self, compiler, connection, **extra_context):  # pragma: mysql
+        # https://github.com/django/django/pull/13398
+        template = "%(function)s(%(expressions)s AS signed integer)"
+        return self.as_sql(compiler, connection, template=template, **extra_context)
 
 
 def _get_django_aggregate(field_type, name):
@@ -62,6 +109,11 @@ def _get_django_aggregate(field_type, name):
             "average": lambda x: models.Avg(Cast(x, output_field=IntegerField())),
             "sum": lambda x: models.Sum(Cast(x, output_field=IntegerField())),
         }[name]
+    if field_type == DurationType and name in ["average", "sum"]:
+        return {
+            "average": lambda x: models.Avg(_CastDuration(x)),
+            "sum": lambda x: models.Sum(_CastDuration(x)),
+        }[name]
     else:
         return {
             # these all have result type number
@@ -115,18 +167,28 @@ def IsNull(field_name):
 
 
 def _get_django_function(name):
-    return {
+    mapping = {
         "year": (functions.ExtractYear, YearType),
         "quarter": (functions.ExtractQuarter, NumberType),
         "month": (functions.ExtractMonth, MonthType),
+        "month_start": (lambda x: functions.TruncMonth(x, DateField()), DateType),
         "day": (functions.ExtractDay, NumberType),
         "week_day": (functions.ExtractWeekDay, WeekDayType),
         "hour": (functions.ExtractHour, NumberType),
         "minute": (functions.ExtractMinute, NumberType),
         "second": (functions.ExtractSecond, NumberType),
         "date": (functions.TruncDate, DateType),
-        "is_null": (IsNull, BooleanType),
-    }[name]
+        "is_null": (IsNull, IsNullType),
+    }
+    if django.VERSION >= (2, 2):  # pragma: no branch
+        mapping.update(
+            {
+                "iso_year": (functions.ExtractIsoYear, YearType),
+                "iso_week": (functions.ExtractWeek, NumberType),
+                "week_start": (lambda x: functions.TruncWeek(x, DateField()), DateType),
+            }
+        )
+    return mapping[name]
 
 
 def s(path):
@@ -139,11 +201,12 @@ def get_model_name(model, sep="."):
 
 def get_fields_for_type(type_):
     aggregates = {
-        a: OrmAggregateField(type_.name, a) for a in _TYPE_AGGREGATES.get(type_, [])
+        aggregate: OrmAggregateField(type_.name, aggregate, res_type)
+        for aggregate, res_type in _TYPE_AGGREGATES[type_]
     }
     functions = {
-        f: OrmFunctionField(type_.name, f, _get_django_function(f)[1])
-        for f in _TYPE_FUNCTIONS[None] + _TYPE_FUNCTIONS.get(type_, [])
+        func: OrmFunctionField(type_.name, func, _get_django_function(func)[1])
+        for func in _TYPE_FUNCTIONS[type_]
     }
     return {**aggregates, **functions}
 
@@ -178,6 +241,9 @@ class OrmBoundField:
     def blank(cls):
         return cls(field=None, previous=None, full_path=[], pretty_path=[])
 
+    def get_format_hints(self, data):
+        return self.type_.get_format_hints(self.path_str, data)
+
 
 @dataclass
 class OrmModel:
@@ -394,8 +460,8 @@ class OrmFileField(OrmConcreteField):
 
 
 class OrmAggregateField(OrmBaseField):
-    def __init__(self, model_name, name):
-        super().__init__(model_name, name, name, type_=NumberType, concrete=True)
+    def __init__(self, model_name, name, type_):
+        super().__init__(model_name, name, name, type_=type_, concrete=True)
 
     def bind(self, previous):
         assert previous
