@@ -1,5 +1,6 @@
 import * as Sentry from "@sentry/browser";
 import React from "react";
+import { sortBy } from "lodash";
 import {
   BrowserRouter,
   Switch,
@@ -47,6 +48,7 @@ class QueryApp extends React.Component {
         cols: response.cols,
         rows: response.rows,
         length: response.length,
+        formatHints: response.formatHints,
         filterErrors: response.filterErrors,
         loading: fetchInProgress,
         error: undefined,
@@ -107,8 +109,11 @@ class QueryApp extends React.Component {
     );
     this.fetchResults(newState)
       .then((response) => {
-        response = { ...response, ...empty };
-        assert.deepStrictEqual(response, request);
+        const res = { ...response, ...empty };
+        res.filters = sortBy(res.filters, ["pathStr"]);
+        const req = { ...request };
+        req.filters = sortBy(req.filters, ["pathStr"]);
+        assert.deepStrictEqual(res, req);
       })
       .catch(this.handleError.bind(this));
   }
