@@ -123,7 +123,9 @@ class Filter extends React.Component {
       <tr>
         <td>
           <SLink onClick={() => query.removeFilter(index)}>close</SLink>{" "}
-          <TLink onClick={() => query.addField(path, prettyPath)}>
+          <TLink
+            onClick={() => query.addField(path, prettyPath, type.defaultSort)}
+          >
             {prettyPath.join(" ")}
           </TLink>{" "}
         </td>
@@ -208,7 +210,11 @@ class Field extends React.Component {
           </td>
           <td>
             {modelField.type ? (
-              <TLink onClick={() => query.addField(path, prettyPath)}>
+              <TLink
+                onClick={() =>
+                  query.addField(path, prettyPath, type.defaultSort)
+                }
+              >
                 {modelField.prettyName}
               </TLink>
             ) : (
@@ -291,6 +297,7 @@ function QueryPage(props) {
     baseUrl,
     loading,
     error,
+    formatHints,
   } = props;
 
   let overlay;
@@ -299,7 +306,9 @@ function QueryPage(props) {
 
   let results;
   if (query.rowFields().length || query.colFields().length)
-    results = <Results {...{ query, rows, cols, body, overlay }} />;
+    results = (
+      <Results {...{ query, rows, cols, body, overlay, formatHints }} />
+    );
   else results = <h2>No fields selected</h2>;
 
   return (
