@@ -1,5 +1,6 @@
-from datetime import datetime
+from datetime import datetime, timedelta
 
+import django
 import pytest
 from django.contrib.admin.options import BaseModelAdmin
 from django.contrib.auth.models import Permission, User
@@ -74,16 +75,16 @@ def pivot_products(db):
     address = models.Address.objects.create(city="london", street="bad")
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
-        datetime(2020, 1, 1),
-        datetime(2020, 2, 1),
-        datetime(2020, 2, 2),
-        datetime(2021, 1, 1),
-        datetime(2021, 1, 2),
-        datetime(2021, 1, 3),
-        datetime(2021, 2, 1),
-        datetime(2021, 2, 2),
-        datetime(2021, 2, 3),
-        datetime(2021, 2, 4),
+        datetime(2020, 1, 1, tzinfo=timezone.utc),
+        datetime(2020, 2, 1, tzinfo=timezone.utc),
+        datetime(2020, 2, 2, tzinfo=timezone.utc),
+        datetime(2021, 1, 1, tzinfo=timezone.utc),
+        datetime(2021, 1, 2, tzinfo=timezone.utc),
+        datetime(2021, 1, 3, tzinfo=timezone.utc),
+        datetime(2021, 2, 1, tzinfo=timezone.utc),
+        datetime(2021, 2, 2, tzinfo=timezone.utc),
+        datetime(2021, 2, 3, tzinfo=timezone.utc),
+        datetime(2021, 2, 4, tzinfo=timezone.utc),
     ]
     for i, dt in enumerate(datetimes):
         models.Product.objects.create(
@@ -261,7 +262,7 @@ def test_get_time_function(get_product_flat):
 @pytest.mark.usefixtures("products")
 def test_get_is_null_function(get_product_flat):
     data = get_product_flat(1, "name+0,producer__address__city__is_null", {})
-    assert data == [["a", False], ["b", False], ["c", True]]
+    assert data == [["a", "NotNull"], ["b", "NotNull"], ["c", "IsNull"]]
 
 
 @pytest.mark.usefixtures("products")
@@ -497,12 +498,12 @@ def test_pivot_sorting_with_empty_cell(get_product_pivot):
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
         # 2021, 1, 1 is notably missing
-        datetime(2021, 2, 1),
-        datetime(2022, 1, 1),
-        datetime(2022, 1, 2),
-        datetime(2022, 2, 1),
-        datetime(2022, 2, 2),
-        datetime(2022, 2, 3),
+        datetime(2021, 2, 1, tzinfo=timezone.utc),
+        datetime(2022, 1, 1, tzinfo=timezone.utc),
+        datetime(2022, 1, 2, tzinfo=timezone.utc),
+        datetime(2022, 2, 1, tzinfo=timezone.utc),
+        datetime(2022, 2, 2, tzinfo=timezone.utc),
+        datetime(2022, 2, 3, tzinfo=timezone.utc),
     ]
     for dt in datetimes:
         models.Product.objects.create(created_time=dt, name=str(dt), producer=producer)
@@ -530,17 +531,17 @@ def test_pivot_sorting_body(get_product_pivot):
     address = models.Address.objects.create(city="london", street="bad")
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
-        datetime(2021, 1, 1),
-        datetime(2021, 2, 1),
-        datetime(2021, 2, 2),
-        datetime(2021, 2, 3),
-        datetime(2022, 1, 1),
-        datetime(2022, 1, 2),
-        datetime(2022, 1, 3),
-        datetime(2022, 1, 4),
-        datetime(2022, 2, 1),
-        datetime(2022, 2, 2),
-        datetime(2022, 2, 3),
+        datetime(2021, 1, 1, tzinfo=timezone.utc),
+        datetime(2021, 2, 1, tzinfo=timezone.utc),
+        datetime(2021, 2, 2, tzinfo=timezone.utc),
+        datetime(2021, 2, 3, tzinfo=timezone.utc),
+        datetime(2022, 1, 1, tzinfo=timezone.utc),
+        datetime(2022, 1, 2, tzinfo=timezone.utc),
+        datetime(2022, 1, 3, tzinfo=timezone.utc),
+        datetime(2022, 1, 4, tzinfo=timezone.utc),
+        datetime(2022, 2, 1, tzinfo=timezone.utc),
+        datetime(2022, 2, 2, tzinfo=timezone.utc),
+        datetime(2022, 2, 3, tzinfo=timezone.utc),
     ]
     for dt in datetimes:
         models.Product.objects.create(created_time=dt, name=str(dt), producer=producer)
@@ -695,3 +696,99 @@ class TestPermissions:
         assert orm_models["core.Normal"] == orm_fields.OrmModel(
             fields=KEYS("admin", "id", "name", "in_admin"), admin=ANY(BaseModelAdmin)
         )
+
+
+@pytest.mark.django_db
+@pytest.mark.parametrize(
+    "lookup,value",
+    [
+        ("", "2020-01-02 03:04:05.000006"),
+        ("year", 2020),
+        ("quarter", 1),
+        ("month", "January"),
+        ("month_start", "2020-01-01"),
+        ("day", 2),
+        ("week_day", "Thursday"),
+        ("hour", 3),
+        ("minute", 4),
+        ("second", 5),
+        ("date", "2020-01-02"),
+    ],
+)
+def test_all_datetime_functions(get_product_flat, lookup, value):
+    models.Product.objects.create(
+        producer=models.Producer.objects.create(),
+        created_time=datetime(2020, 1, 2, 3, 4, 5, 6, tzinfo=timezone.utc),
+    )
+
+    fields = f"created_time__{lookup}" if lookup else "created_time"
+    data = get_product_flat(1, fields, {})
+    assert data == [[value]]
+
+
+@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
+@pytest.mark.django_db
+@pytest.mark.parametrize(
+    "lookup,value", [("iso_year", 2020), ("iso_week", 1), ("week_start", "2019-12-30")]
+)
+def test_all_datetime_functions_2_2(get_product_flat, lookup, value):
+    models.Product.objects.create(
+        producer=models.Producer.objects.create(),
+        created_time=datetime(2020, 1, 2, 3, 4, 5, 6, tzinfo=timezone.utc),
+    )
+
+    fields = f"created_time__{lookup}" if lookup else "created_time"
+    data = get_product_flat(1, fields, {})
+    assert data == [[value]]
+
+
+@pytest.mark.django_db
+@pytest.mark.parametrize(
+    "aggregation,value",
+    [
+        ("count", 3),
+        # these would be nice but sqlite
+        # ("average", ""),
+        # ("min", ""),
+        # ("max", ""),
+    ],
+)
+def test_datetime_aggregations(get_product_flat, aggregation, value):
+    producer = models.Producer.objects.create()
+    models.Product.objects.create(
+        producer=producer, created_time=datetime(2020, 1, 1, tzinfo=timezone.utc)
+    )
+    models.Product.objects.create(
+        producer=producer, created_time=datetime(2020, 1, 2, tzinfo=timezone.utc)
+    )
+    models.Product.objects.create(
+        producer=producer, created_time=datetime(2020, 1, 2, tzinfo=timezone.utc)
+    )
+    models.Product.objects.create(
+        producer=producer, created_time=datetime(2020, 1, 3, tzinfo=timezone.utc)
+    )
+
+    data = get_product_flat(1, f"created_time__{aggregation}", {})
+    assert data == [[value]]
+
+
+@pytest.mark.django_db
+@pytest.mark.parametrize(
+    "aggregation,value",
+    [
+        ("sum", "8:00:00"),
+        ("average", "2:00:00"),
+        ("count", 3),
+        ("min", "1:00:00"),
+        ("max", "3:00:00"),
+    ],
+)
+def test_duration_aggregations(get_product_flat, aggregation, value):
+    producer = models.Producer.objects.create()
+    models.Product.objects.create(producer=producer, duration=timedelta(hours=1))
+    models.Product.objects.create(producer=producer, duration=timedelta(hours=2))
+    models.Product.objects.create(producer=producer, duration=timedelta(hours=2))
+    models.Product.objects.create(producer=producer, duration=timedelta(hours=3))
+
+    data = get_product_flat(1, f"duration__{aggregation}", {})
+    assert data == [[value]]
