@@ -2,8 +2,10 @@ import csv
 import json
 from datetime import datetime
 
+import django
 import pytest
 from django.contrib.auth.models import User
+from django.utils import timezone
 
 import data_browser.models
 
@@ -29,12 +31,12 @@ def pivot_products(db):
     address = models.Address.objects.create(city="london", street="bad")
     producer = models.Producer.objects.create(name="Bob", address=address)
     datetimes = [
-        datetime(2020, 1, 1),
-        datetime(2020, 2, 1),
-        datetime(2020, 2, 2),
-        datetime(2021, 1, 1),
-        datetime(2021, 1, 2),
-        datetime(2021, 1, 3),
+        datetime(2020, 1, 1, tzinfo=timezone.utc),
+        datetime(2020, 2, 1, tzinfo=timezone.utc),
+        datetime(2020, 2, 2, tzinfo=timezone.utc),
+        datetime(2021, 1, 1, tzinfo=timezone.utc),
+        datetime(2021, 1, 2, tzinfo=timezone.utc),
+        datetime(2021, 1, 3, tzinfo=timezone.utc),
     ]
     for i, dt in enumerate(datetimes):
         models.Product.objects.create(
@@ -42,6 +44,7 @@ def pivot_products(db):
         )
 
 
+@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_html(admin_client, snapshot):
     res = admin_client.get(
         "/data_browser/query/core.Product/size-0,name+1,size_unit.html?size__lt=2&id__gt=0"
@@ -60,6 +63,7 @@ def test_query_query(admin_client, snapshot):
     snapshot.assert_match(query, "query")
 
 
+@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_html_no_perms(admin_user, admin_client, snapshot):
     admin_user.is_superuser = False
     admin_user.save()
@@ -69,6 +73,7 @@ def test_query_html_no_perms(admin_user, admin_client, snapshot):
     snapshot.assert_match(config, "config")
 
 
+@pytest.mark.skipif(django.VERSION < (2, 2), reason="Django version 2.2 required")
 def test_query_ctx(admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
@@ -271,6 +276,16 @@ def test_view_json(admin_client):
         "cols": [{}],
         "body": [[{}, {}]],
         "length": 2,
+        "formatHints": {
+            "name": {},
+            "size": {
+                "decimalPlaces": 0,
+                "significantFigures": 3,
+                "lowCutOff": 0.0001,
+                "highCutOff": 1e10,
+            },
+            "size_unit": {},
+        },
     }
 
     view.owner = User.objects.create(is_staff=True)
